# wealth
Visualizing financial relations and evolutions.

Stock picking is hard, and has a [terrible track record](https://www.cnbc.com/2020/09/18/stock-picking-has-a-terrible-track-record-and-its-getting-worse.html).

If you're going to do it, two things would go a long way in mitigating the 
mess of information amongst the mass of noise: 
- building intuition based on multi-faceted facts
- being able to test ideas at the speed of thought

These are just tools to help out in that direction.

To install:	```pip install wealth```

![Stocks Swarm](https://github.com/thorwhalen/wealth/blob/master/misc/stock_swarm.gif?raw=true "Stocks swarm from 2010 to 2020")
